@@ -1,7 +1,7 @@
 from rest_framework import serializers
 
 from netbox.api.serializers import WritableNestedSerializer
-from netbox_storage.models import Filesystem, Drive, LinuxVolume
+from netbox_storage.models import Filesystem, Drive, WindowsVolume
 
 
 #
@@ -19,17 +19,16 @@ class NestedFilesystemSerializer(WritableNestedSerializer):
 
 
 #
-# LinuxVolume
+# WindowsVolume
 #
-
-class NestedLinuxVolumeSerializer(WritableNestedSerializer):
+class NestedWindowsVolumeSerializer(WritableNestedSerializer):
     url = serializers.HyperlinkedIdentityField(
-        view_name="plugins-api:netbox_storage-api:linuxvolume-detail"
+        view_name="plugins-api:netbox_storage-api:windowsvolume-detail"
     )
 
     class Meta:
-        model = LinuxVolume
-        fields = ["id", "url", "display", "vg_name"]
+        model = WindowsVolume
+        fields = ["id", "url", "display", "drive_name"]
 
 
 #
