@@ -1,3 +1,4 @@
+from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
     IntegerField,
@@ -20,6 +21,12 @@ from virtualization.models import Cluster, VirtualMachine
 
 class DriveForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
+    size = IntegerField(
+        required=True,
+        label="Size (GB)",
+        help_text="The size of the drive e.g. 25",
+        validators=[MinValueValidator(1)],
+    )
     cluster = DynamicModelChoiceField(
         queryset=Cluster.objects.all(),
         required=False,
@@ -33,6 +40,11 @@ class DriveForm(NetBoxModelForm):
         queryset=VirtualMachine.objects.all(),
         required=False
     )
+    description = CharField(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. Drive 1 on SSD Cluster",
+    )
 
     class Meta:
         model = Drive
