@@ -1,5 +1,6 @@
+from django.core.validators import MinValueValidator
 from django.forms import (
-    CharField,
+    CharField, IntegerField,
 )
 
 from netbox.forms import (
@@ -28,29 +29,43 @@ class WindowsVolumeForm(NetBoxModelForm):
         label="Filesystem Name",
         help_text="The Filesystem of the Volume e.g. NTFS",
     )
-    drives = DynamicModelMultipleChoiceField(
-        queryset=Drive.objects.all(),
-        label="Drives",
-        required=False
+    description = CharField(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. C: System Volume",
     )
     virtual_machine = DynamicModelChoiceField(
         queryset=VirtualMachine.objects.all(),
         required=False
     )
+    drives = DynamicModelMultipleChoiceField(
+        queryset=Drive.objects.all(),
+        label="Drives",
+        required=False,
+        help_text="The mapped drives to the volume e.g. Hard Drive 1",
+    )
+    size = IntegerField(
+        required=True,
+        label="Size (GB)",
+        help_text="The size of the disk size mapping e.g. 25",
+        validators=[MinValueValidator(1)],
+    )
 
     fieldsets = (
         (
-            "Windows Volume",
+            "Windows Volume Configuration",
             (
                 "drive_name",
                 "fs",
-                "virtual_machine"
+                "virtual_machine",
+                "description"
             ),
         ),
         (
             "Drive Configuration",
             (
                 "drives",
+                "size"
             ),
         ),
     )
