@@ -49,6 +49,10 @@ class Drive(NetBoxModel):
         self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
         super(Drive, self).save(*args, **kwargs)
 
+    @property
+    def docs_url(self):
+        return f'https://confluence.ti8m.ch/docs/models/drive/'
+
 
 class Filesystem(NetBoxModel):
     filesystem = models.CharField(
